@@ -1,12 +1,14 @@
-#!/usr/bin/perl
-
 package MooseX::Types::DateTime;
+BEGIN {
+  $MooseX::Types::DateTime::AUTHORITY = 'cpan:NUFFIN';
+}
+# git description: MooseX-Types-DateTime-0.06-18-g336ac0e
+$MooseX::Types::DateTime::VERSION = '0.09';
 
 use strict;
 use warnings;
 
-our $VERSION = "0.08";
-
+use 5.008003;
 use Moose 0.41 ();
 use DateTime 0.4302 ();
 use DateTime::Duration 0.4302 ();
@@ -15,7 +17,7 @@ use DateTime::TimeZone 0.95 ();
 
 use MooseX::Types::Moose 0.30 qw/Num HashRef Str/;
 
-use namespace::clean 0.08;
+use namespace::autoclean;
 
 use MooseX::Types 0.30 -declare => [qw( DateTime Duration TimeZone Locale Now )];
 
@@ -46,16 +48,16 @@ subtype( Now,
 
 our %coercions = (
     DateTime => [
-		from Num, via { 'DateTime'->from_epoch( epoch => $_ ) },
-		from HashRef, via { 'DateTime'->new( %$_ ) },
-		from Now, via { 'DateTime'->now },
+        from Num, via { 'DateTime'->from_epoch( epoch => $_ ) },
+        from HashRef, via { 'DateTime'->new( %$_ ) },
+        from Now, via { 'DateTime'->now },
     ],
     "DateTime::Duration" => [
-		from Num, via { DateTime::Duration->new( seconds => $_ ) },
-		from HashRef, via { DateTime::Duration->new( %$_ ) },
+        from Num, via { DateTime::Duration->new( seconds => $_ ) },
+        from HashRef, via { DateTime::Duration->new( %$_ ) },
     ],
     "DateTime::TimeZone" => [
-		from Str, via { DateTime::TimeZone->new( name => $_ ) },
+        from Str, via { DateTime::TimeZone->new( name => $_ ) },
     ],
     "DateTime::Locale" => [
         from Moose::Util::TypeConstraints::find_or_create_isa_type_constraint("Locale::Maketext"),
@@ -73,11 +75,11 @@ for my $type ( "DateTime::Duration", Duration ) {
 }
 
 for my $type ( "DateTime::TimeZone", TimeZone ) {
-	coerce $type => @{ $coercions{"DateTime::TimeZone"} };
+    coerce $type => @{ $coercions{"DateTime::TimeZone"} };
 }
 
 for my $type ( "DateTime::Locale", Locale ) {
-	coerce $type => @{ $coercions{"DateTime::Locale"} };
+    coerce $type => @{ $coercions{"DateTime::Locale"} };
 }
 
 __PACKAGE__
@@ -91,11 +93,15 @@ __END__
 MooseX::Types::DateTime - L<DateTime> related constraints and coercions for
 Moose
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 Export Example:
 
-	use MooseX::Types::DateTime qw(TimeZone);
+    use MooseX::Types::DateTime qw(TimeZone);
 
     has time_zone => (
         isa => TimeZone,
@@ -105,9 +111,11 @@ Export Example:
 
     Class->new( time_zone => "Africa/Timbuktu" );
 
+=for stopwords Namespaced
+
 Namespaced Example:
 
-	use MooseX::Types::DateTime;
+    use MooseX::Types::DateTime;
 
     has time_zone => (
         isa => 'DateTime::TimeZone',
@@ -134,8 +142,8 @@ A class type for L<DateTime>.
 
 =item from C<Num>
 
-Uses L<DateTime/from_epoch>. Floating values will be used for subsecond
-percision, see L<DateTime> for details.
+Uses L<DateTime/from_epoch>. Floating values will be used for sub-second
+precision, see L<DateTime> for details.
 
 =item from C<HashRef>
 
@@ -204,11 +212,6 @@ L<MooseX::Types::DateTime::MoreCoercions>
 
 L<DateTime>, L<DateTimeX::Easy>
 
-=head1 VERSION CONTROL
-
-This module is maintained using git. You can get the latest version from
-L<git://git.moose.perl.org/MooseX-Types-DateTime.git>.
-
 =head1 AUTHOR
 
 Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
@@ -217,8 +220,8 @@ John Napiorkowski E<lt>jjn1056 at yahoo.comE<gt>
 
 =head1 COPYRIGHT
 
-	Copyright (c) 2008 Yuval Kogman. All rights reserved
-	This program is free software; you can redistribute
-	it and/or modify it under the same terms as Perl itself.
+    Copyright (c) 2008 Yuval Kogman. All rights reserved
+    This program is free software; you can redistribute
+    it and/or modify it under the same terms as Perl itself.
 
 =cut
